#
# spec file for package perl-Tree-DAG_Node
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define cpan_name Tree-DAG_Node
Name:           perl-Tree-DAG_Node
Version:        1.31
Release:        lp150.1.1
Summary:        An N-ary tree
License:        Artistic-1.0 OR GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Tree-DAG_Node/
Source0:        https://cpan.metacpan.org/authors/id/R/RS/RSAVAGE/%{cpan_name}-%{version}.tgz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Slurp::Tiny) >= 0.003
BuildRequires:  perl(File::Spec) >= 3.4
BuildRequires:  perl(File::Temp) >= 0.19
BuildRequires:  perl(Test::More) >= 1.001002
Requires:       perl(File::Slurp::Tiny) >= 0.003
BuildArch:      noarch
%{perl_requires}

%description
This class encapsulates/makes/manipulates objects that represent nodes in a
tree structure. The tree structure is not an object itself, but is emergent
from the linkages you create between nodes. This class provides the methods
for making linkages that can be used to build up a tree, while preventing
you from ever making any kinds of linkages which are not allowed in a tree
(such as having a node be its own mother or ancestor, or having a node have
two mothers).

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make %{?_smp_mflags} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Wed Feb 21 2018 pmonrealgonzalez@suse.com
- Cleaned the spec file with spec-cleaner
* Wed Feb 21 2018 pmonrealgonzalez@suse.com
- updated to 1.31
  1.31  2018-02-14T09:08:00
  - Clarify licence issue by changing the reference in the
    DAG_Node.pm file from Artistic V 2 to Perl, so it now
    matches what I preemptively put in Makefile.PL and the
    LICENSE file.
  - Sean Burke has kindly agreed to this change.
    $thanx x $many to Gregor Herrmann (Debian Perl Group) for
    reporting this via github.
* Thu Feb  8 2018 coolo@suse.com
- updated to 1.30
  see /usr/share/doc/packages/perl-Tree-DAG_Node/Changelog.ini
* Sun Oct  8 2017 coolo@suse.com
- updated to 1.29
  see /usr/share/doc/packages/perl-Tree-DAG_Node/Changelog.ini
* Fri Mar 14 2014 coolo@suse.com
- updated to 1.22
  - t/read.tree.t was still using File::Slurp :-(.
  1.21  Thu Feb 13 11:14:00 2014
  - Switch from File::Slurp to File::Slurp::Tiny, on the advice of Karen Etheridge. See RT#92976.
  1.20  Fri Jan 31 09:46:00 2014
  - After a private email from Paul Howarth (yea!) I see I need File::Temp V 0.19 because that's
    the version which introduced the newdir() method, as used in the test suite. Sorry for the churn.
  1.19  Thu Jan 30 09:24:00 2014
  - Set pre-req File::Temp version # to 0 (back from 0.2301). See D A Golden's blog entry:
    http://www.dagolden.com/index.php/2293/why-installing-distzilla-is-slow-and-what-you-can-do-about-it/.
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.18
  - No changes, code or otherwise, except for the version # in the *.pm, this file, and Changelog.ini.
  - Somehow a corrupted version got uploaded to search.cpan.org, so I've just changed the version #.
    The file on MetaCPAN was fine.
  - Thanx to Rob (Sisyphus) for reporting this.
  1.17  Mon Sep 16 15:24:00 2013
  - Write test temp files in :raw mode as well as utf-8, for MS Windows users.
  - Take the opportunity to change all utf8 to utf-8, as per the docs for Encode,
    except for 'use warnings  qw(FATAL utf8);', which doesn't accept utf-8 :-(.
  1.16  Mon Sep  9 09;26:00 2013
  - Accept a patch (slightly modified by me) from Tom Molesworth (see RT#88501):
    Remove 'use open qw(:std :utf8);' because of its global effect.
    Replace Perl6::Slurp with File::Slurp, using the latter's binmode option for the encoding.
    Fix docs where I'd erroneously said File::Slurp didn't support utf8.
  1.15  Fri Sep  6 11:10:00 2013
  - Replace Path::Tiny with File::Spec, because the former's list of dependencies is soooo long :-(.
    Changed files: t/read.tree.t, Build.PL and Makefile.PL.
    See: RT#88435 for an explanation.
  - Move t/pod.t to xt/author/pod.t.
  1.14  Wed Sep  4 13:44:00 2013
  - Document the copy() method.
  - Patch the copy() method so it respects the {no_attribute_copy => 1} option.
  - Add method read_tree(), for text files. It uses Perl6::Slurp (which supports utf8).
  - Add methods read_attributes() and string2hashref($s) for use by read_tree().
  - Add t/read.tree.t to test read_tree().
  - Add t/tree.utf8.attrbiutes.txt, in utf8, for use by t/read.tree.t.
  - Add t/tree.with.attributes.txt and t/tree.without.attributes.txt for use by t/read.tree.t.
  - Make Perl V 5.8.1 a pre-req so we have access to the utf8 pragma.
  1.13  Mon Aug 12 17:16:00 2013
  - Change the values accepted for the no_attributes option from undef and 1 to 0 and 1.
    If undef is used, it becomes 0, so pre-existing code will not change behaviour.
    This makes it easier to pass 0 or 1 from the command line, since there is no default value available.
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.12
  - Change text in README referring to licence to match text in body of source, since it was in conflict
    with the Artistic Licence V 2.0.
    This was requested by Petr Pisar who packages stuff for Red Hat.
  - Rename CHANGES to Changes as per CPAN::Changes::SPEC.
  - Various spelling fixes in the docs, as kindly reported by dsteinbrunner.
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.11
  - Correct the date (2012 -> 2013) in this file used for V 1.10.
  - Correct the text at L<Tree::DAG_Node/AUTHOR> so it refers to Artistic License 2.0,
    which now matches what it says in Build.PL and Makefile.PL. Resolves RT#83088.
  - Change t/pod.t to look for Test::Pod 1.45, but comment out Test::Pod in Build.PL and Makefile.PL.
    This means Test::Pod is not used at all if it is not installed. As per RT#83077.
  - For pre-reqs such as strict, warnings, etc, which ship with Perl, set the version # to 0.
    Reported as RT#80663 by Father Chrysostomos for Tree::DAG_Node.
  - New maintainer: Ron Savage
  - Pre-emptive apologies for any changes which are not back-compat. No such problems are expected, but the
    introduction of new methods may disconcert some viewers.
  - Fix RT#78858, reported by Gene Boggs. Audit code for similar problems.
  - Fix RT#79506. reported by Ron Savage.
  - Rename ChangeLog to CHANGES, and add Changelog.ini.
  - Replace all uses of cyclicity_fault() and Carp::croak with die.
  - Remove unused methods: decommission_root(), cyclicity_allowed(), cyclicity_fault(), inaugurate_root(),
    no_cyclicity() and _update_links(). OK - cyclicity_fault() was called once. It just died.
  - Add methods: format_node(), hashref2string(), is_root(), node2string(), tree2string().
    tree2string($opts, $node) - unlike draw_ascii_tree() - can optionally print the tree starting at any node.
    Override format_node(), hashref2string(), and node2string() if desired.
  - Reformat the POD big-time.
  - Add Build.PL.
  - Re-write Makefile.PL.
  - Remove use vars(@ISA $Debug $VERSION). Replace latter 2 with 'our ...'.
  - Rename t/00_about_verbose.t to t/about.perl.t.
  - Add scripts/cut.and.paste.subtrees.pl. Warning: Some trees get into an infinite loop.
  - Add t/cut.and.paste.subtrees.t.        Warning: Some trees get into an infinite loop.
  - Document the options (discouraged by Sean) supported in the call to new($hashref).
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Wed Mar 12 2008 anicka@suse.cz
- package created (version 1.06)
